==> am_mod_grp_0_1.zip: am_mod_grp_0_1/components/grp/template/barnraiser_01/poll_list.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>


<div class="col_main">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_polls'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($polls)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<?php
					foreach ($polls as $key => $i):
					
					?>
					<tr>
						<td valign="top">
							<a href="index.php?amn=grp_poll_edit&amp;group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $i['poll_id'];?>"><?php echo $i['poll_question'];?></a><br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_options'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<a href="index.php?amn=grp_poll_edit&amp;group_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_add_poll'];?></a><br />
				</p>
			</div>
		</div>
	</div>
</div>

==> am_mod_grp_0_4.zip: am_mod_grp_0_4/components/grp/template/barnraiser_01/poll_list.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>


<div class="col_main">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_polls'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($polls)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<?php
					foreach ($polls as $key => $i):
					
					?>
					<tr>
						<td valign="top">
							<a href="index.php?amn=grp_poll_edit&amp;group_id=<?php echo $group['group_id'];?>&amp;poll_id=<?php echo $i['poll_id'];?>"><?php echo $i['poll_question'];?></a><br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_options'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<a href="index.php?amn=grp_poll_edit&amp;group_id=<?php echo $group['group_id'];?>"><?php echo $lang['href_add_poll'];?></a><br />
				</p>
			</div>
		</div>
	</div>
</div>
